package logwire.core.bo.object;

import logwire.core.bo.annotation.Column;
import logwire.core.bo.annotation.Composite;
import logwire.core.bo.field.BizExpando;
import logwire.core.bo.field.BizOne;

import java.time.OffsetDateTime;
import java.util.Map;

/**
 * BO 生成的Model,audit=false version=true domain=true, 指定ID为主键，非AUTO；audit由BO控制
 * BO 子表字段(多对多、数组、大文本)生成的Model，audit/version/domain都为false
 */
public abstract class BizObject extends ModelObject {
    /**
     * 事务类型 insert/update/delete
     */
    private String txCode;

    /**
     * 当事务类型为update时，记录修改过的字段
     */
    private Map<String, Object> updatedFields;

    @Column(label = "主键")
    private Long id;// BO 的ID全部为雪花ID
    @Column(label = "版本号")
    private int version;
    @Column(label = "BO名称")
    private String boName;
    @Column(label = "创建用户")
    private BizOne<User> createUser;
    @Column(label = "创建时间")
    private OffsetDateTime createDate;
    @Column(label = "最后修改用户")
    private BizOne<User> updateUser;
    @Column(label = "最后修改时间")
    private OffsetDateTime updateDate;
    @Composite(label = "项目扩展字段", prefix = "exp_")
    private BizExpando exps;
    @Column(label = "域")
    private String domain;


    @Override
    public Object getId() {
        return id;
    }


    public String getTxCode() {
        return txCode;
    }

    public void setTxCode(String txCode) {
        this.txCode = txCode;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public String getBoName() {
        return boName;
    }

    public void setBoName(String boName) {
        this.boName = boName;
    }

    public BizOne<User> getCreateUser() {
        return createUser;
    }

    public void setCreateUser(BizOne<User> createUser) {
        this.createUser = createUser;
    }

    public OffsetDateTime getCreateDate() {
        return createDate;
    }

    public void setCreateDate(OffsetDateTime createDate) {
        this.createDate = createDate;
    }

    public BizOne<User> getUpdateUser() {
        return updateUser;
    }

    public void setUpdateUser(BizOne<User> updateUser) {
        this.updateUser = updateUser;
    }

    public OffsetDateTime getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(OffsetDateTime updateDate) {
        this.updateDate = updateDate;
    }

    public BizExpando getExps() {
        return exps;
    }

    public void setExps(BizExpando exps) {
        this.exps = exps;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }
}
